/* MCVE v3.x C API
   (c) 2002 by Main Street Softworks, Inc.
   Written by Brad House

   This API is being released to the public domain to be modified and used in any manor the holder of this code sees fit.
   For any questions please contact  support@mainstreetsoftworks.com
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "libmcve_main.h"
#include "mcve.h"


// Standard includes ... all platforms
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <sys/types.h>
#include <errno.h>
#include <fcntl.h>

//Win32 includes
#ifdef WIN32
#include <io.h>
#include <winsock2.h>
#include <sys/timeb.h>
#else // !Win32
// UNIX/POSIX includes
#include <unistd.h>
#include <sys/socket.h>
#ifndef DISABLE_IP
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#endif
#include <sys/time.h>
#include <dirent.h>
#ifdef MCVE_PTHREAD
#include <pthread.h>
#endif // MCVE_PTHREAD

#endif //Win32

//SSL includes
#ifdef ENABLE_SSL
#include <openssl/crypto.h>
#include <openssl/x509.h>
#include <openssl/pem.h>
#include <openssl/ssl.h>
#include <openssl/err.h>
#include <openssl/rand.h>
#endif
#include "libmcve_misc.h"
#include "libmcve_locking.h"

int MCVE_IP_Response_Start(char *string)
{
  char *temp;
  temp=strchr(string, 0x02); // Find the STX
  if (temp == NULL)
    return(-1);
  return(strlen(string)-strlen(temp));
}

int MCVE_IP_Response_End(char *string, int start)
{
   char *tempstr, *temp;
   tempstr=string+start;
   temp=strchr(tempstr, 0x03); // Find ETX
   if (temp == NULL)
     return(-1);
   return(strlen(string)-strlen(temp));
}

//returns ending point (at which to cut inbuf) -- STX*ETX
int MCVE_IP_Get_Response(char *instring, char **outstring)
{
  int start=0, end=0;

  start=MCVE_IP_Response_Start(instring);
  if (start == -1) return(-1);
  end=MCVE_IP_Response_End(instring, start);
  if (end == -1) return(-1);
  outstring[0]=MCVE_midstr(instring, start, end-start+1);
  return(end+1);
}

int MCVE_IP_Get_Response_Identifier(char *response, char **identifier)
{
  int start=1;
  int end=0;
  char *temp;
  temp=strchr(response, 0x1c);  //Find FS
  if (temp == NULL) return(0);
  end=strlen(response)-strlen(temp);
  identifier[0]=MCVE_midstr(response, start, end-start);
  return(1);
}

int MCVE_IP_Get_Response_Message(char *response, char **message)
{
  int start, end;
  char *temp;
  temp=strchr(response, 0x1c);  //Find FS
  if (temp == NULL) return(0);
  start=strlen(response)-strlen(temp)+1;
  end=strlen(response)-1;
  message[0]=MCVE_midstr(response, start, end-start);
  return(1);
}

long MCVE_ReadLine(char *string, long start, char **line)
{
  char *temp, *temp2;
  long end;
  temp2=string+start;
  temp=strchr(temp2, '\n');
  if (temp == NULL)  return(-1);
  end=strlen(string)-strlen(temp)+1;
  line[0]=MCVE_midstr(string, start, end-start-2);
  return(end);
}

int MCVE_ParseLine(char *line, char **option, char **value)
{
  char *temp;
  long pos;
  temp=strchr(line, '=');
  if (temp == NULL) return(0);  
  pos=strlen(line)-strlen(temp);
  option[0]=MCVE_midstr(line, 0, pos);
  value[0]=MCVE_midstr(line, pos+1, strlen(line)-(pos+1));
  return(1);
}


